@@ -1,13 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from contextlib import contextmanager
 from dbpoolpy.dbconnect import DBConnection
 from dbpoolpy.dbhelper.mysql import MysqlHelper
+from dbpoolpy.constants import DBTYPE
 
 
 class MySQLConnection(DBConnection, MysqlHelper):
-    dbtype = "mysql"
+    __dbtype__ = DBTYPE.MYSQL
 
 
     def connect(self):
@@ -41,7 +41,7 @@ class MySQLConnection(DBConnection, MysqlHelper):
         cur.close()
 
         print('server=%s|func=connect|id=%d|name=%s|user=%s|role=%s|addr=%s:%d|db=%s' % (
-                 self.dbtype,
+                 self.__dbtype__,
                  self._conn_id % 10000,
                  self._name,
                  self._kwargs.get('user', ''),
