@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from contextlib import contextmanager
 from dbpoolpy.dbconnect import DBConnection
 from dbpoolpy.dbhelper.postgresql import PostgresqlHelper
+from dbpoolpy.constants import DBTYPE
 
 
 class PostgreSQLConnection(DBConnection, PostgresqlHelper):
-    dbtype = "postgresql"
+    __dbtype__ = DBTYPE.POSTGRESQL
 
 
     def escape(self, s):
