@@ -3,7 +3,6 @@ from math import ceil
 import datetime
 from collections import namedtuple
 from dbpoolpy.utils import timesql
-from dbpoolpy import pager
 from contextlib import contextmanager
 from dbpoolpy.config import settings
 from dbpoolpy.constants import DBTYPE
@@ -101,7 +100,7 @@ class Base:
                 self._where_args.extend(list(item))
                 return op + ' (%s)' % (",".join(["%s"] * len(item)))
             else:
-                self._where_args.append(item)
+                self._where_args.append(tuple(item))
                 return op + ' %s'
         elif op == 'between':
             assert isinstance(item, (list, tuple)) and len(item) == 2
