@@ -21,9 +21,14 @@ class DBPoolBase(object):
         pass
 
 class DBPool(DBPoolBase):
-    def __init__(self, name, engine, mincached=1, maxconnections=20, timeout=10, *args, **kwargs):
+    def __init__(
+            self, name, engine, dbtype=None,
+            mincached=1, maxconnections=20, timeout=10,
+            *args, **kwargs
+        ):
         self._name = name                              # 数据库连接池名称
         self._engine = engine                          # 数据库连接引擎，满足DB API 2.0规范
+        self._dbtype = dbtype or settings.DB_TYPE      # 连接池类型
         self._mincached = mincached                    # 连接池最小缓存个数
         self._maxconnections = maxconnections          # 连接池最大连接个数
         self._timeout = timeout                        # 连接不使用状态释放超时时间
@@ -36,12 +41,12 @@ class DBPool(DBPoolBase):
         self.open(self._mincached)
 
     def conn_cls(self):
-        assert settings.DB_TYPE in DBTYPE.values(), 'DB_TYPE error'
-        if settings.DB_TYPE == DBTYPE.MYSQL:
+        assert self._dbtype in DBTYPE.values(), 'DB_TYPE error'
+        if self._dbtype == DBTYPE.MYSQL:
             return MySQLConnection
-        elif settings.DB_TYPE == DBTYPE.POSTGRESQL:
+        elif self._dbtype == DBTYPE.POSTGRESQL:
             return PostgreSQLConnection
-        elif settings.DB_TYPE == DBTYPE.SQLITE3:
+        elif self._dbtype == DBTYPE.SQLITE3:
             return SQLite3Connection
 
     def synchronize(func):
